Page 39 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 39

Home

    Ye are of your father the devil, and the lusts of your
    father ye will do. He was a murderer from the beginning,
    and abode not in the truth, because there is no truth in
    him. When he speaketh a lie, he speaketh of his own: for
    he is a liar, and the father of it.

    John 8:44

    Here, in a stinging indictment delivered to the Jews
    who were seeking to kill Him, Jesus identified the
    primary source of falsehood and murder as Satanic. As

    we progress through events of the French Revolution it
    will become evident that the primary motivation, beyond
    lust for wealth and power, was a Satanically-inspired
    desire of evil for the sake of evil.

    After firmly estabhshing themselves in Bavaria (a part
    of what is now Germany), the leaders of the Illuminati
    began to work toward their international goal of
    overthrowing all existing governments and, eventually,
    ruling the world.

    At that time (1789) France was the richest and most
    populous nation on the continent of Europe; and it was
    here that the "great experiment in Democracy" began.
    The battle cry was "liberty, equality, and fraternity." The
    vehicle was Socialism.

    34

    Chapter 6

    The French Revolution